#
# spec file for package python-glfw
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-glfw
Version:        2.8.0
Release:        1.1
Summary:        A ctypes-based wrapper for GLFW3
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/FlorianRhiem/pyGLFW
Source:         https://files.pythonhosted.org/packages/source/g/glfw/glfw-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  libglfw3
BuildRequires:  python-rpm-macros
Requires:       libglfw3
BuildArch:      noarch
%python_subpackages

%description
This module provides Python bindings for GLFW . It is a
ctypes wrapper which keeps very close to the original GLFW API,
except for:

-  function names use the pythonic ``words_with_underscores`` notation
   instead of ``camelCase``
-  ``GLFW_`` and ``glfw`` prefixes have been removed, as their function
   is replaced by the module namespace
-  structs have been replaced with Python sequences
-  functions like ``glfwGetMonitors`` return a list instead of a pointer
   and an object count
-  Gamma ramps use floats between 0.0 and 1.0 instead of unsigned shorts
-  GLFW errors are reported as ``glfw.GLFWError`` exceptions if no error
   callback is set (use ``glfw.ERROR_REPORTING=False`` to disable this)

%prep
%setup -q -n glfw-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# no upstream tests

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/glfw
%{python_sitelib}/glfw-*.dist-info

%changelog
* Thu Jan 16 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.8.0
  * Update to GLFW 3.4
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Limit Python files matched in %%files section
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 2.7.0:
  * Included GLFW 3.4 functions and definitions without preview
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.5:
  * Fixed Python version check
* Wed Dec 20 2023 Dirk Müller <dmueller@suse.com>
- update to 2.6.4:
  * Updated to GLFW 3.3.9
* Sun Dec 17 2023 Dirk Müller <dmueller@suse.com>
- update to 2.6.3:
  * Fixed wrapper for glfwGetMonitorWorkarea
  * Implemented search for GLFW library specific to frozen
    executables
  * Revert changes made in 2.6.0
  * Do not search for GLFW library when running in a frozen
    executable
  * Use multiprocessing for library version detection on non-
    Windows systems
  * Fixed package version in CHANGELOG.md and glfw/__init__.py
  * Added more wrappers for unreleased macros
  * Added support for PYGLFW_LIBRARY_VARIANT
  * Added warnings for deprecated functions
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- [2.5.5] - 2022-09-07
  Added wrappers for unreleased macros
  Fixed set_monitor_user_pointer and get_monitor_user_pointer
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- [2.5.4] - 2022-07-23
  Updated to GLFW 3.3.8
- [2.5.3] - 2022-04-09
  Updated to GLFW 3.3.7
- [2.5.2] - 2022-04-01
  Fixed swapped HAT_DOWN and HAT_RIGHT constants
- [2.5.1] - 2022-02-27
  Updated to GLFW 3.3.6
- [2.5.0] - 2021-12-18
  Added /usr/lib/arm-linux-gnueabihf to library search paths
- [2.4.0] - 2021-11-07
  Added macOS wheels for arm64
  Added wrappers for unreleased macros and functions
  Updated to GLFW 3.3.5
- [2.3.0] - 2021-10-01
  Added /opt/homebrew/lib to library search paths
- [2.2.0] - 2021-09-09
  Added Linux wheels for aarch64
  Updated to GLFW 3.3.4
- [2.1.0] - 2021-02-28
  Updated to GLFW 3.3.3
- [2.0.0] - 2020-10-04
  Changed default error reporting method to warn
  Allow dict for ERROR_REPORTING
- [1.12.0] - 2020-07-10
  Added support for CFFI pointers for Vulkan objects
* Wed Jul  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.11.2
  * Fixed missing parameter in set_window_opacity
  * Replaced non-ASCII whitespace
  * Fixed a TypeError in _GLFWgamepadstate
* Thu Mar  5 2020 pgajdos@suse.com
- version update to 1.11.0
  [#]# [1.11.0] - 2020-02-21
  - Updated to GLFW 3.3.2
  - Include support for both X11 and Wayland libraries in the wheel
  [#]# [1.10.1] - 2020-01-21
  - Fixed default error callback name
  [#]# [1.10.0] - 2020-01-19
  - Added more options to error reporting
  [#]# [1.9.1] - 2020-01-08
  - Added conda search path for Windows
  [#]# [1.9.0] - 2019-12-30
  - Added wrappers for native functions
  [#]# [1.8.7] - 2019-12-10
  - Fixed glfwGetMonitorContentScale
  [#]# [1.8.6] - 2019-12-09
  - Added macOS wheels
  - Added Microsoft Visual C++ runtime libraries to Windows wheels
  [#]# [1.8.5] - 2019-11-28
  - Added /usr/lib/aarch64-linux-gnu/ to library search paths
  - Fix pointer types in get_window_content_scale
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.8.3:
  * Updated the GLFW version in the wheels to 3.3
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 1.8.2
  * Added the sys.prefix/lib to the search path
  * Added the changelog back to the source distribution
* Tue May 21 2019 pgajdos@suse.com
- version update to 1.8.0
  * Update for GLFW 3.3
  * Fixed typo set_get_window_frame_size
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.7.1:
  * Fixed a bug in set_window_icon and added support for PIL/pillow Image objects
  * Improved packaging
  * Added NORMALIZE_GAMMA_RAMPS, use namedtuples for structs and moved library loading to glfw.library
  * Added glfw.GLFW for the naming convention used by the GLFW C API
  * Fixed exception re-raising for Python 2
- There are no tests, so remove test conditional
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version
